@@ -1,5 +1,5 @@
 package Path::Resolver::Resolver::FileSystem;
-our $VERSION = '1.000';
+our $VERSION = '2.000';
 
 # ABSTRACT: find files in the filesystem
 use Moose;
@@ -7,6 +7,7 @@ with 'Path::Resolver::Role::Resolver';
 
 use Carp ();
 use File::Spec;
+use Path::Resolver::Util;
 
 
 has root => (
@@ -27,11 +28,7 @@ sub content_for {
     @$path,
   );
 
-  return unless -e $abs_path;
-
-  open my $fh, '<', $abs_path or Carp::confess("can't open $abs_path: $!");
-  my $content = do { local $/; <$fh> };
-  return \$content;
+  return Path::Resolver::Util->_content_at_abs_path($abs_path);
 }
 
 no Moose;
@@ -47,7 +44,7 @@ Path::Resolver::Resolver::FileSystem - find files in the filesystem
 
 =head1 VERSION
 
-version 1.000
+version 2.000
 
 =head1 ATTRIBUTES
 
